import type { InstallerOptions } from './factory.js';
import type Storage from '../storage.js';
import type Oas from 'oas';
export default abstract class CodeGenerator {
    spec: Oas;
    specPath: string;
    identifier: string;
    userAgent: string;
    requiredPackages: Record<string, {
        dependencyType: 'production' | 'development';
        reason: string;
        url?: string;
        version: string;
    }>;
    constructor(spec: Oas, specPath: string, identifier: string);
    abstract generate(): Promise<Record<string, string>>;
    abstract install(storage: Storage, opts?: InstallerOptions): Promise<void>;
    /**
     * It would be better if this were an abstract function but TS/JS doesn't have support for that so
     * we instead have to rely on throwing a `TypeError` if it's not been implemented instead of a
     * build-time error.
     *
     * @see {@link https://github.com/microsoft/TypeScript/issues/34516}
     */
    static uninstall(storage: Storage, opts?: InstallerOptions): Promise<void>;
    abstract compile(storage: Storage, opts?: InstallerOptions): Promise<void>;
    hasRequiredPackages(): boolean;
}
//# sourceMappingURL=codegenerator.d.ts.map